#
# spec file for package kdeclarative
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5Declarative5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kdeclarative
Version:        5.116.0
Release:        1.9
Summary:        Integration of QML and KDE workspaces
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  libepoxy-devel
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5GlobalAccel) >= %{_kf5_version}
BuildRequires:  cmake(KF5GuiAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{_kf5_version}
BuildRequires:  cmake(KF5Package) >= %{_kf5_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{_kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5Gui) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}

%description
KDeclarative provides integration of QML and KDE workspaces.

%package -n %{lname}
Summary:        Integration of QML and KDE workspaces
# QQmlPropertyMap leaks private but exported QObjectPrivate symbol
# https://bugreports.qt.io/browse/QTBUG-46433 and https://bugs.launchpad.net/bugs/1426335
%requires_eq    libQt5Core5

%description -n %{lname}
KDeclarative provides integration of QML and KDE workspaces.

%package -n libKF5QuickAddons5
Summary:        Integration of QML and KDE workspaces

%description -n libKF5QuickAddons5
KDeclarative provides integration of QML and KDE workspaces.

%package -n libKF5CalendarEvents5
Summary:        Integration of QML and KDE workspaces

%description -n libKF5CalendarEvents5
KDeclarative provides integration of QML and KDE workspaces.

%package components
Summary:        KDeclarative QML components
Requires:       kirigami2 >= %{_kf5_version}

%description components
KDeclarative provides integration of QML and KDE workspaces.

%package tools
Summary:        KDeclarative tools

%description tools
KDeclarative provides integration of QML and KDE workspaces.

%package devel
Summary:        Integration of QML and KDE workspaces: Build Environment
Requires:       %{lname} = %{version}
Requires:       %{name}-components = %{version}
Requires:       libKF5CalendarEvents5 = %{version}
Requires:       libKF5QuickAddons5 = %{version}
Requires:       cmake(KF5Config) >= %{_kf5_version}
Requires:       cmake(KF5CoreAddons) >= %{_kf5_version}
Requires:       cmake(KF5Package) >= %{_kf5_version}
Requires:       cmake(Qt5Qml) >= %{qt5_version}

%description devel
KDeclarative provides integration of QML and KDE workspaces.
Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%fdupes %{buildroot}

%find_lang kdeclarative5

%ldconfig_scriptlets -n %{lname}
%ldconfig_scriptlets -n libKF5QuickAddons5
%ldconfig_scriptlets -n libKF5CalendarEvents5

%files -n %{lname}-lang -f kdeclarative5.lang

%files -n %{lname}
%license LICENSES/*
%doc README*
%{_kf5_libdir}/libKF5Declarative.so.*

%files -n libKF5QuickAddons5
%{_kf5_libdir}/libKF5QuickAddons.so.*

%files -n libKF5CalendarEvents5
%{_kf5_libdir}/libKF5CalendarEvents.so.*

%files components
%{_kf5_libdir}/qt5/qml/

%files tools
%{_kf5_bindir}/kpackagelauncherqml

%files devel
%{_kf5_libdir}/libKF5Declarative.so
%{_kf5_libdir}/libKF5QuickAddons.so
%{_kf5_libdir}/libKF5CalendarEvents.so
%{_kf5_libdir}/cmake/KF5Declarative/
%{_kf5_includedir}/KDeclarative/
%{_kf5_mkspecsdir}/qt_KDeclarative.pri
%{_kf5_mkspecsdir}/qt_QuickAddons.pri

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- Changes since 5.114.0:
  * Show GridDelegate labels as plaintext (kde#480106)
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- Changes since 5.109.0:
  * GridDelegate: lazy load menu
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Remove code variants for building with Qt 6
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Guard nullable property access, and bind instead of assigning once
  * CalendarEventsPlugin: fix wrong deprecation for signal alternateDateReady
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * API dox: add some minimal docs to namespace & classes to trigger coverage
  * API dox: cover CalendarEvents in generated QCH file
  * Overhaul configmodule docs
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Guard nullable property access, and bind instead of assigning once
  * AbstractKCM: Rewrite padding expressions to be more readable
  * Add import aliases, bump internal import versions as needed
  * Drop unused QML imports
  * [managedconfigmodule] Fix deprecation comments
  * [configmodule] Deprecate constructor without metadata
  * [configmodule] Deprecate setAboutData
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Remove unused QtGraphicalEffects import
  * Fix anchors error in AbstractKCM & SimpleKCM types
  * QML/JS: Prefer const over let, and use strict === equality
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * draganddrop replace QList::first() with constFirst()
  * calendarevents: add new alternate date ready signal and deprecate the old one
  * Support modifierOnlyAllowed in KeySequenceItem
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * Deprecate unused parts of KWindowSystem import
  * tests: add test for multiple KeySequenceItems
  * Fixed KF 5.100 compilation
  * SimpleKCM: Account for flickable's margins when deciding to show separators
  * SimpleKCM: Clean up a bit
  * Fix build
  * Deprecate QIconItem
  * Use const/let for JS variables as appropriate
  * Sync header and footer separator code to SimpleKCM (kde#461435)
  * AbstractKCM: remove KF6 TODO
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Make QQmlContext's contextObject outlive the QQmlContext
  * Completely deprecate KDeclarative class
  * Port manual test app away from deprecated KDeclarative API
  * Add Qt6 windows CI support
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * KeySequenceItem: Restore the previous value when it fails
  * Remove project() calls from subdirs
  * KeySequenceItem: Allow detecting when the key sequence is cleared (kde#458799)
  * KeySequenceItem: Use the helper's shortcut instead of duplicating them
  * KeySequenceItem: Disable clear button when there's no key sequence (kde#458798)
  * KeySequenceItem: Cancel sequence recording when pressing the button
  * KeySequenceItem: Remove workaround, it was addressed upstream
  * KeySequenceItem: Show a cancel button when recording (kde#458796)
  * GridDelegate: show tooltip when `toolTip` is empty and title/caption is elided
  * AbstractKCM: make footer top padding optional
  * [kquickaddons/configmodule] Make getters const
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * KQuickAddons::ConfigModule: Call QmlObject constructor with shared pointer directly
  * KDeclarative::setupEngine: Use KQuickIconProvider
  * Deprecate KDeclarative::setupEngine
  * Do not build kpackagelauncherqml when building without deprecations
  * Deprecate KPackage related methods in QmlObject
  * Add FreeBSD Qt6 CI support
  * fallbacktaphandler remove duplicate parentheses
  * Deprecate KDeclarative::setupQmlJsDebugger
  * KDeclarative::setupEngine: Wrap code that uses deprecated method in deprecation wrappers
  * Deprecate KDeclarative::runtimePlatform and related methods
  * Port tests away from QQC1
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * GridDelegate: Improve accessibility for inline buttons
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * kquickcontrols: give main button a description
  * kquickcontrols: give Clear button a tooltip
  * Don't duplicate headers between cpp/.h files
  * qmlcontrols: make `isPlatformX11` and `isPlatformWayland` constant
  * qmlcontrols: add `isPlatformX11` and `isPlatformWayland` in `KWindowSystemProxy`
  * qmlcontrols: add `Pad` fill mode in `QImageItem` (kde#389623)
  * [KeySequenceItem] Replace attached object ToolTip with an instance
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * qmlcontrols: bump `QtQuick` import version to 2.15 for GridViewInternal
  * port to standard C++ smart pointers where possible
  * Use the correct engine variable
  * Remove KDeclarative instance from QmlObject
  * QmlObject: Use std::shared_ptr to properly track the lifetime of QQmlEngine (kde#451790)
  * Move type registrations to the plugin initialization
  * calendareventsplugin: Add label property
  * calendareventsplugin: Add support for alternate dates and sub-labels
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Add PlaceholderMessage to GridView KCMs
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Deprecate KQuickAddons::QtQuickSettings::init
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Fix double deleting of NetworkAccessManagerFactory (kde#450507)
  * Delete networkAccessManagerFactory when we delete the engine
  * Improve Open[app]() functions (kde#443984)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * proper position for top separator
  * [KeySequenceItem] Make keySequence «non-null», «non-undefined» and «non-""»
  * [KeySequenceItem] Fix code style and bump QML imports
  * Make QML code depend less on the `kcm` context property
  * Fix QT_NO_OPENGL build after 66c5bb0efa
  * kquickcontrols: Improve accessibility in ColorButton.qml (kde#449282)
  * GridDelegate: Focus on the delegate after a menu is closed
  * GridDelegate: Open menu when Menu key is pressed
  * Add CI qt6 support
  * Exclude epoxy in qt6 => exclude plotter class
  * Fix some compile error against qt6
  * Deprecate KDeclarative::ConfigPropertyMap in favor of KConfigPropertyMap
  * Apply fix from Volker
  * Prepare build system for building against qt6
  * fix autotests, avoid clash with bin/data on Windows
  * Don't use KGlobalAccel on Windows
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Add a few Qt6 compilation fixes
  * Drop lib prefix when building for Windows
  * follow method name changes in kglobalaccel
  * Need include here (qt6 build)
  * Use "frameless" style for grid and scroll view QtQuick KCMs by default
  * Detect overlapping shortcuts
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * KeySequenceItem: Make sure we record on the correct window (kde#445277)
  * Deprecate KRun KIO plugin
  * Add missing override keyword
  * Allow KCM kpackages to use metadata of C++ plugin
  * add takeLast() slot to ConfigModule
  * Fix overflowing text properly
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * GridDelegate: don't let labels overflow (kde#444707)
  * Use a readonly property to control KCM margins
  * [configmodule] Deprecate aboutData
  * [ConfigModule] Allow creating KCMs without KAboutData
  * [ConfigModule] Deprecate ctors that take KAboutData and KPluginMetaData
  * Don't explicitly build shared libs
  * Expose KAuthorized enum as dynamic properties to QML
  * Add FreeBSD CI
  * KCM GridDelegate: Display a blue line when the delegate has active focus
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * Make sure the object gets destroyed before the view
  * Add support for static builds
  * SimpleKCM: Remove last vestiges of previously-removed properties
  * SimpleKCM: remove custom header and footer handling
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * document clipboard more extensively
  * Add missing PRIVATE part for linking in cmake
  * Try to fix Android build via linking GLESv3
  * qtquicksettings: Add workaround for Nvidia Wayland
  * GridDelegate: Fix non-existant context property
  * AbstractKCM: Fix padding when header/footer is not visible
  * Don't use the KIO AccessManager on Android
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Implement aspect ratio correction for Lanczos effect
  * Introduce Lanczos filter element
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Allow compiling against Qt configured with -no-opengl
  * Allow compiling against Qt configured with -no-qml-debug
  * [GridDelegate] Remove lightening overlay on hover (kde#438462)
  * KCM: polish the documentation of the CMake bits
  * include QScreen in kquickcontrolsaddonsplugin.h to fix build on macOS
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * [KeySequenceItem] Display ampersands in shortcuts (kde#437718)
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Fix mem leak found by ASAN
  * Add the ContextualHelpButton from some kcms in this import
  * [GridDelegate] Show inline controls for active item too
  * Make GridView KCMs handle keyboard focus in an accessible manner
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- No code change since 5.80.0
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * don't use mousehover effects on mobile
  * [GridDelegate] Fix vertical misalignment when showing a subtitle
  * [GridDelegate] Remove centering hack
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * 1 column lower limit on mobile 2 elsewhere
  * allow single column items
  * KeySequenceItem: Assign empty string on clear instead of undefined (kde#432106)
  * typo--
  * Disambiguate selected vs hovered states for GridDelegate (kde#406914)
  * Use Single mode by default
  * GridDelegate: remove hover animations
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Switch to Findepoxy provided by ECM
  * KCMShell: Add support for passing arguments
  * Remove ifdefs, we require Qt 5.14 now
  * Workaround crash with GL detection and kwin_wayland
  * [KQuickAddons] QtQuickSettings::checkBackend() for fallback to software backend (kde#422995)
  * [abstractkcm] Fix import version in code example
  * Avoid setting QSG_RENDER_LOOP if set already
  * ConfigPropertyMap : load property's default value in the map
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Sync margins from AbstractKCM into SimpleKCM
  * Remove obsolete license text
  * Relicense file to LGPL-2.0-or-later
  * Rewrite KeySequenceItem (and helper) to use KeySequenceRecorder (kde#407395)
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * [abstractkcm] Set explicit padding
  * [abstractkcm] Don't remove padding on mobile
  * [simplekcm] Remove custom padding handling
  * [kcmcontrols] Remove duplicated code
  * Add source to KDeclarativeMouseEvent
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * reparent overlaysheets to the root
  * Make GridViewKCM and ScrollVieKCM inherit from AbstractKCM
  * Use consistent margins
  * Add getter method for subPages
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * QML for I18n are added in KF 5.17
  * Relicense files to LGPL-2.0-or-later
  * Block shortcuts when recording key sequences (kde#425979)
  * Fix typo, qdebug--
  * Add SettingHighlighter as a manual version of the highlighting done by SettingStateBinding
  * [autotests] Fix unstable BSD test
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * [KKeySequenceItem] Make Meta+Shift+num shortcuts work
  * Expose checkForConflictsAgainst property
  * Add a new AbstractKCM class
  * Using no deprecated enum Qt::MiddleButton
  * typo--
  * Remove obsolete COPYING files
  * Port KRunProxy away from KRun
  * Fix warning: zero as null pointer constant
  * KDeclarative: Convert copyright statements to SPDX expressions
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * SettingStateBinding : expose whether non default highlight is enabled
  * Make sure KF5CoreAddons is installed before using KF5Declarative
  * Add KF5::CoreAddons to public interface for KF5::QuickAddons
  * Introduce SettingState* elements to ease KCM writing.
  * fix version in new api
  * support config notifications in configpropertymap
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Port to CommandLauncherJob
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Improve dox
  * Fix #include guards
  * Create kcmshell.openSystemSettings() and kcmshell.openInfoCenter() functions
  * Port KKeySequenceItem to QQC2
  * Pixel align children of GridViewInternal
- Drop upstream patch:
  * 0001-Pixel-align-children-of-GridViewInternal.patch
* Thu May  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Pixel-align-children-of-GridViewInternal.patch
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Introduce SettingState* elements to ease KCM writing
  * Properly name the content of the kcmcontrols project
  * Tweak kcmcontrols docs
  * Add startCapture method
  * [KeySequenceHelper] Work around Meta modifier behavior
  * Also relase the window in the destructor
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Introduce api for passive notifications
  * [KCM Controls GridDelegate] Use `ShadowedRectangle`
  * [kcmcontrols] Respect header/footer visibility
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Expose capture signal on KeySequenceItem
  * Fix size of the header in GridViewKCM (kde#417347)
  * Allow ManagedConfigModule derived class to register explicitly KCoreConfigSkeleton.
  * Allow to use KPropertySkeletonItem in ManagedConfigModule
  * respect header's visibility
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * typo--
  * Correctly compute bottom margin for grid delegates with subtitles
  * Port away from deprecated IconSize() method
  * [ConfigModule] Say which package is invalid
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * [KeySequenceHelper] Grab actual window when embedded
  * Update the obsolete projects.kde.org URL
  * Add optional subtitle to grid delegate
  * document colorbutton with an example
  * [QImageItem/QPixmapItem] Don't lose precision during calculation
  * kdeclarative EBN spelling cleanup
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * EBN kdeclarative transfer protocol cleanup
  * Adapt to change in KConfigCompiler
  * MAke it compile without deprecated method
  * make header and footer visible when they get content
  * support qqmlfileselectors
  * Allow to disable autosave behavior in ConfigPropertyMap
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Use compile time checked connect
  * Make the settingChanged() slot protected.
  * Get KQuickAddons::ConfigModule to expose if we're in the defaults state
  * Grab the keyboard when KeySequenceItem is recording
  * Add ManagedConfigModule
  * Remove outdated comment about [$e] expansion
  * Use ECMGenerateExportHeader to manage deprecated API better
  * [ConfigModule] Expose mainUi component status and error string
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Delete QQmlObjectSharedEngine context in sync with QQmlObject
  * [KDeclarative] Port away from deprecated QWheelEvent methods
  * [KDeclarative] Port from deprecated QWheelEvent::delta() to angleDelta()
  * [KDeclarative] Port away from deprecated QQuickWindow::sendEvent
  * [KDeclarative autotests] Replace fork of old modeltest with QAbstractItemModelTester
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Warn if KPackage is invalid
  * Remove unused includes
  * [GridDelegate] Don't select unselected item when clicking on any of its
    action buttons (kde#404536)
  * [ColorButton] Forward accepted signal from ColorDialog
  * use zero-based coordinate system on the plot
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Scrollview - Don't fill the parent with the view (kde#407643)
  * introduce FallbackTapHandler
  * Fix typo - GridView -> ScrollView
  * KRun QML proxy: port away from deprecated KRun API
  * Docs: fix bad example code
  * KRun QML proxy: fix path/URL confusion
  * Calendar events: allow plugins to show event details
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * [GridDelegate] Fix gaps in corners of thumbnailArea highlight
  * get rid of blockSignals
  * [KCM GridDelegate] Silence warning
  * [KCM GridDelegate] Take into account implicitCellHeight for inner delegate height
  * Fix GridDelegate icon
  * Fix fragile comparison to i18n("None") and describe behavior in docs (kde#407999)
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Fix qmldir files
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * [KeySequenceItem] Make the clear button have the same height as shortcut button
  * Plotter: Scope GL Program to lifespan of scenegraph node (kde#403453)
  * use the base implementation hints
  * KeySequenceHelperPrivate::updateShortcutDisplay: Don't show english text to the user
  * [ConfigModule] Pass initial properties in push()
  * Enable glGetGraphicsResetStatus support by default on Qt >= 5.13 (kde#364766)
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [kdeclarative] compile without foreach
  * [GridViewKCM] Fix implicit width calculation
  * move the gridview in a separate file
  * Avoid fractionals in GridDelegate sizes and alignments
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * use KPackage::fileUrl to support rcc KCMs packages
  * Remove not necessary flags
  * [GridDelegate] Fix long labels blending into each other (kde#404389)
  * [GridViewKCM] improve contrast and legibility for delegates' inline hover buttons (kde#395510)
  * Correct the accept flag of the event object on DragMove (kde#396011)
  * Use different "None" item icon in grid view KCMs
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * [KCM Controls GridView] Add remove animation
  * KDeclarative: Delete copy constructor and assignment operator
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * don't show separators on mobile
  * root.contentItem instead of just contentItem
  * Add the missing api for multilevel KCMs to control the columns
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Normalize signal/slot
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * API dox QCH creation: fix "linking" to kconfig docs
  * make push/pop part of ConfigModule API
  * Use reserve()
  * Use QVariant::toFoo() where possible
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Avoid potential detach on range-loops with non-const Qt containers
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Revert "ensure we are always writing in the engine's root context"
  * Attach property to "delegate" (kde#397367)
  * add an implicit size
  * [KCM GridDelegate] Use layer effect only on OpenGL backend
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * ensure we are always writing in the engine's root context
  * better readability
  * Improve API docs a bit
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove QT definitions duplicated from KDEFrameworkCompilerSettings or dead
  * check the node actually has a valid texture (kde#395554)
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Revert "GHNS button"
  * Set kcm context property on the correct context
  * GHNS button
  * [Plotter] Don't render if m_node is null (kde#394283)
  * assign the contentItem
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Load NV graphics reset based on config
  * ScrollViewKCM
  * [KUserProxy] Adjust to accounts service (kde#384107)
  * Plasma mobile optimizations
  * Make room for footer and header.
  * base on the proper tooltip
  * don't use tooltips if empty
  * new resize policy (kde#391910)
  * Warning--
  * support actions visibility
  * Support nvidia reset notifications in QtQuickViews
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Remove useless QT_VERSION_CHECK
  * Remove not necessary QtCore and co
  * Setup QQmlEngine only once in QmlObject
  * Minor: Fix -Wmismatched-tags warning
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Fix the build failure on armhf/aarch64
  * Kill QmlObjectIncubationController
  * disconnect render() on window change (kde#388508, kde#374280, kde#365052, kde#343576)
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * API dox: note @since & whattodo with deprecated KDeclarative::initialize()
  * [ConfigModule] Re-use QML context and engine if any
  * [ConfigPropertyMap] Add missing include
  * [ConfigPropertyMap] Don't emit valueChanged on initial creation
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * crash--
  * it was split
  * fix build
  * Qml controls for kcm creation
* Wed Dec 20 2017 lbeltrame@kde.org
- Dropped patches, now upstream:
  - MouseEventListener-Allow-accepting-mouse-event.patch
* Mon Dec 18 2017 wbauer@tmo.at
- Add MouseEventListener-Allow-accepting-mouse-event.patch to make
  it possible to fix double context menu issue with Qt 5.10 in
  plasma5-desktop (kde#387199)
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Make it compile on windows
  * make it compile with QT_NO_CAST_FROM_ASCII/QT_NO_CAST_FROM_BYTEARRAY
  * [MouseEventListener] Allow accepting mouse event
  * use a single QML engine
  * add some metadata
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Add explicit keyword
  * Item can't be null here
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Remove copy of the GPL
  * Relicense to LGPL2.1+ (part 2)
  * Relicense some files to LGPL2.1+
  * Added openService() method to KRunProxy
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * None
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * fix plasmashell unsetting QSG_RENDER_LOOP
  * API dox: fix @param to use name of parameter, not type
  * API dox: use @param for normal parameter listing, not @arg
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * KKeySequenceItem: make it possible to record Ctrl+Num+1 as a shortcut.
  * Start drag with press and hold on touch events (kde#368698)
  * Don't rely on QQuickWindow delivering QEvent::Ungrab as mouseUngrabEvent (as it no longer does in Qt 5.8+) (kde#380354)
  * [FEATURE] Option to build & install QCH file with the public API dox
- Drop upstreamed patches:
  * 0001-Don-t-rely-on-QQuickWindow-delivering-QEvent-Ungrab-.patch
* Sat Jun 17 2017 fabian@ritter-vogt.de
- Add upstream patch to account for behavioural change in Qt 5.8+
  regarding ungrab events:
  * 0001-Don-t-rely-on-QQuickWindow-delivering-QEvent-Ungrab-.patch
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Consistently emit MouseEventListener::pressed signal
  * Use explicit flag constructor instead of nullptr
  * Don't leak MimeData object (kde#380270)
  * API Dox: note forwarding CamelCase files as class headers
  * API Dox: add some non-empty class/namespace docs where missing
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Don't set ItemHasContents in DropArea
  * Don't accept hover events in the DragArea
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
  * With Qt >= 5.8 use the new API to set scene graph backend
  * Don't set acceptHoverEvents in DragArea as we don't use them
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * [QtQuickRendererSettings] Fix default to be empty instead of "false"
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * [kpackagelauncherqml] Assume desktop file name is same as pluginId
  * Load QtQuick rendering settings from a config file and set default
  * icondialog.cpp - proper compile fix that doesn't shadow m_dialog
  * Fix crash when no QApplication is available
  * Expose translation domain
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Actually emit valueChanged
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Make epoxy optional
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Support selected state
  * KCMShell import can now be used to query for whether opening
    a KCM is actually allowed
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Don't crash if we have no openGL context
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Uniform use of std::numeric_limits
  * [DeclarativeDragArea] Don't override "text" of mime data
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Don't call null object pointer (kde#347962)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Fri Feb 26 2016 hrvoje.senjan@gmail.com
- Add %%requires_eq libQt5Core5 to the libKF5Declarative5 subpackage
  * QQmlPropertyMap leaks private but exported QObjectPrivate symbol:
    https://bugreports.qt.io/browse/QTBUG-46433 and
    https://bugs.launchpad.net/bugs/1426335
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Clean up dependencies for KDeclarative/QuickAddons
  * [KWindowSystemProxy] Add setter for showingDesktop
  * DropArea: Fix correctly ignoring dragEnter event with
    preventStealing
  * DragArea: Implement grabbing delegate item
  * DragDropEvent: Add ignore() function
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Mon Feb  1 2016 hrvoje.senjan@gmail.com
- Add missing libKF5CalendarEvents5 to baselibs.conf
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * [DragArea] Add dragActive property
  * [KQuickControlsAddons MimeDatabase] Expose QMimeType comment
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Port KDeclarative to use KI18n directly
  * DragArea delegateImage can now be a string from which an icon
    is automatically created
  * Add new CalendarEvents library
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * ConfigPropertyMap can now be queried for immutable config
    options using the isImmutable(key) method
  * Unbox QJSValue in config property map
  * EventGenerator: Add support for sending wheel events
  * Fix lost QuickViewSharedEngine initialSize on initializing.
  * Fix critical regression for QuickViewSharedEngine by commit
    3792923639b1c480fd622f7d4d31f6f888c925b9
  * Make pre-specified view size precede initial object size in
    QuickViewSharedEngine
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Small improvements in ColumnProxyModel
  * Make it possible for applications to know path to homeDir
  * Move EventForge from the desktop containment
  * Provide enabled property for QIconItem.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Fix deprecated KRun::run call
  * Same behavior of MouseArea to map coords of filtered child
    events
  * Detect initial face icon being created
  * Don't refresh the entire window when we render the plotter
    (kde#348385)
  * add the userPaths context property
  * Don't choke on empty QIconItem
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
- Drop patches merged upstream:
  0001-Only-resize-plot-texture-if-size-actually-changes.patch
  0001-Don-t-refresh-the-entire-window-when-we-render-the-p.patch
* Mon Jul 27 2015 hrvoje.senjan@gmail.com
- Added 0001-Don-t-refresh-the-entire-window-when-we-render-the-p.patch
  (kde#348385)
* Wed Jul  8 2015 hrvoje.senjan@gmail.com
- Added 0001-Only-resize-plot-texture-if-size-actually-changes.patch
  (kde#346134, kde#348385)
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Add QQC clone of KColorButton
  * Assign a QmlObject for each kdeclarative instance when possible
  * Make Qt.quit() from QML code work
  * Merge branch 'mart/singleQmlEngineExperiment'
  * Implement sizeHint based on implicitWidth/height
  * Subclass of QmlObject with static engine
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Support creation of ConfigModule from KPluginMetdata
  * Fix pressAndhold events
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Fix crash in texture cache
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Added kcoreaddons-devel Requires to devel subpackage
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Prefer exposing lists to QML with QJsonArray
  * Handle non default devicePixelRatios in images
  * Expose hasUrls in DeclarativeMimeData
  * Allow users to configure how many horizontal lines are drawn
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
- Added kpackage-devel BuildRequires
- Added pkgconfig(Qt5Qml), kconfig-devel and kpackage-devel to
  devel package requires
- Drop kio-devel from devel package requires
- New tools subpackage, containing kpackagelauncherqml tool
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Added a plotter component
  * Added overload method for Formats::formatDuration taking int
  * New properties paintedWidth and paintedHeight added to
    QPixmapItem and QImageItem
  * Fixed painting QImageItem and QPixmapItem
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
- Added libepoxy-devel BuildRequires
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Use Qt's method of blocking for component completion rather
    than our own
  * Make it possible to delay initialization of object incubated
    from QmlObject
  * Add guard when trying to access root object before
    component is complete
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Optimize IconItem in QIconItem in memory and speed
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
- Split out libKF5QuickAddons library, and QML components into
  separate subpackages
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KDeclarative: added org.kde.kio component.
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
- Drop af7c0f8194.patch, merged upstream
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
- Add af7c0f8194.patch, to improve QML translation API
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
- Added kwidgetsaddons-devel, kwindowsystem-devel, kglobalaccel-devel,
  kcoreaddons-devel and kguiaddons-devel BuildRequires, needed for
  building components imported from plasma-framework
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kdeclarative package
